#! /usr/bin/env python

import argparse
import subprocess
import sys
import os


def build(args):
    parser = argparse.ArgumentParser(description='Compiling the documentation')
    parser.add_argument('-v', '--verbose', action='store_true', help='verbose mode')
    parser.add_argument('--update_issues', action='store_true', help='update issues')
    args = parser.parse_args(args)
    if args.verbose:
        print("build start")
    if args.update_issues:
        if args.verbose:
            print("get issues")
        p = subprocess.run(["deno", "run", "-A","tools/getIssue.ts", "--path","./build/issues.json"])
        p.check_returncode()
    if args.verbose:
        print("build issues")
    p = subprocess.run(["deno", "run", "-A","tools/printDocument.ts", "--overall", "--path", "./build/issues.json", "--outpath", "./build/overall.md"])
    p.check_returncode()
    p = subprocess.run(["deno", "run", "-A","tools/printDocument.ts", "--path", "./build/issues.json", "--outpath", "./build/specific.md"])
    p.check_returncode()

def help(_args):
    global commandList
    print("subcommands:")
    for command in commandList.keys():
        print("\t", command)

commandList = {
    'build': build,
    'help': help
}

def main():
    args = sys.argv
    if len(args) < 2:
        print("no subcommand", file=sys.stderr)
        help(args)
        return
    _command = args[0]
    subCommand = args[1]
    if subCommand not in commandList:
        print("Command not found", file=sys.stderr)
        help(args)
        sys.exit(1)
    args = args[2:]
    os.makedirs("build", exist_ok=True)
    commandList[subCommand](args)

if __name__ == '__main__':
    main()